@@ -33,13 +33,13 @@
 #include <regex.h>
 
 #include "../core/weechat.h"
-#include "../core/wee-config.h"
-#include "../core/wee-eval.h"
-#include "../core/wee-hashtable.h"
-#include "../core/wee-hook.h"
-#include "../core/wee-string.h"
-#include "../core/wee-utf8.h"
-#include "../core/wee-util.h"
+#include "../core/core-config.h"
+#include "../core/core-eval.h"
+#include "../core/core-hashtable.h"
+#include "../core/core-hook.h"
+#include "../core/core-string.h"
+#include "../core/core-utf8.h"
+#include "../core/core-util.h"
 #include "../plugins/plugin.h"
 #include "gui-chat.h"
 #include "gui-buffer.h"
@@ -390,12 +390,13 @@ gui_chat_get_word_info (struct t_gui_window *window,
  */
 
 char *
-gui_chat_get_time_string (time_t date, int date_usec)
+gui_chat_get_time_string (time_t date, int date_usec, int highlight)
 {
     char text_time[128], text_time2[(128*3)+16], text_time_char[2];
     char *text_with_color;
     int i, time_first_digit, time_last_digit, last_color;
     struct timeval tv;
+    struct t_hashtable *extra_vars;
 
     if (date == 0)
         return NULL;
@@ -413,7 +414,14 @@ gui_chat_get_time_string (time_t date, int date_usec)
 
     if (strstr (text_time, "${"))
     {
-        text_with_color = eval_expression (text_time, NULL, NULL, NULL);
+        extra_vars = hashtable_new (32,
+                                    WEECHAT_HASHTABLE_STRING,
+                                    WEECHAT_HASHTABLE_STRING,
+                                    NULL, NULL);
+        if (extra_vars)
+            hashtable_set (extra_vars, "highlight", (highlight) ? "1" : "0");
+        text_with_color = eval_expression (text_time, NULL, extra_vars, NULL);
+        hashtable_free (extra_vars);
         if (text_with_color)
         {
             if (strcmp (text_time, text_with_color) != 0)
@@ -510,7 +518,7 @@ gui_chat_get_time_length ()
 
     length = 0;
     gettimeofday (&tv_now, NULL);
-    text_time = gui_chat_get_time_string (tv_now.tv_sec, tv_now.tv_usec);
+    text_time = gui_chat_get_time_string (tv_now.tv_sec, tv_now.tv_usec, 0);
 
     if (text_time)
     {
@@ -539,11 +547,11 @@ gui_chat_change_time_format ()
         {
             if (ptr_line->data->date != 0)
             {
-                if (ptr_line->data->str_time)
-                    free (ptr_line->data->str_time);
+                free (ptr_line->data->str_time);
                 ptr_line->data->str_time = gui_chat_get_time_string (
                     ptr_line->data->date,
-                    ptr_line->data->date_usec);
+                    ptr_line->data->date_usec,
+                    ptr_line->data->highlight);
             }
         }
     }
@@ -669,8 +677,8 @@ gui_chat_printf_datetime_tags_internal (struct t_gui_buffer *buffer,
     if (modifier_data && string)
     {
         snprintf (modifier_data, length_data,
-                  "0x%lx;%s",
-                  (unsigned long)buffer,
+                  "%p;%s",
+                  buffer,
                   (tags) ? tags : "");
         if (display_time)
         {
@@ -745,8 +753,7 @@ gui_chat_printf_datetime_tags_internal (struct t_gui_buffer *buffer,
                     new_line->data->date = new_line->data->date_printed;
                     new_line->data->date_usec = new_line->data->date_usec_printed;
                 }
-                if (new_line->data->prefix)
-                    string_shared_free (new_line->data->prefix);
+                string_shared_free (new_line->data->prefix);
                 if (pos_prefix)
                 {
                     new_line->data->prefix = (char *)string_shared_get (pos_prefix);
@@ -758,8 +765,7 @@ gui_chat_printf_datetime_tags_internal (struct t_gui_buffer *buffer,
                 }
                 new_line->data->prefix_length = gui_chat_strlen_screen (
                     new_line->data->prefix);
-                if (new_line->data->message)
-                    free (new_line->data->message);
+                free (new_line->data->message);
                 new_line->data->message = strdup (ptr_msg);
             }
         }
@@ -774,12 +780,9 @@ gui_chat_printf_datetime_tags_internal (struct t_gui_buffer *buffer,
 
     gui_buffer_ask_chat_refresh (new_line->data->buffer, 1);
 
-    if (string)
-        free (string);
-    if (modifier_data)
-        free (modifier_data);
-    if (new_string)
-        free (new_string);
+    free (string);
+    free (modifier_data);
+    free (new_string);
 
     return;
 
@@ -789,12 +792,9 @@ no_print:
         gui_line_free_data (new_line);
         free (new_line);
     }
-    if (string)
-        free (string);
-    if (modifier_data)
-        free (modifier_data);
-    if (new_string)
-        free (new_string);
+    free (string);
+    free (modifier_data);
+    free (new_string);
 }
 
 /*
